@@ -514,6 +514,7 @@ T = TypeVar("T", str, int, float, bool, datetime, date, list, Connection)
 
 
 def Parameter(
+    name: str,
     description: str = None,
     type: Union[Type[T], Connection] = str,
     default: T = "MISSING",
@@ -532,9 +533,21 @@ def Parameter(
     * Connection
 
     Args:
+        name: The parameter name. Must be a valid python identifier.
         description: Description / help text
         type: should be the actual python type, e.g. `type=str` or `type=datetime`
         default: default value. If not set explicitly, the parameter is assumed to be required.
             May be set to None
     """
     pass
+
+def respond_to_request(request_key: str, payload: dict):
+    """Respond with a payload to a request identified by a request_key
+
+    Args:
+        request_key: The key of the request to respond to. This is the value of the
+            "patterns_request_key" field added to the table for requests that wait for a
+            response.
+        payload: Data that will be json encoded and used as the body of the response.
+    """
+    pass
